@@ -4,18 +4,19 @@
 ###
 ### This version produces the header information for use with MathJax
 ###
-### DJS 27/08/2011
+### DJS 15/12/2012
 date()
 options(width=80)
 
 ### Set some state variables
 opSys <- Sys.info()["sysname"]
 if (opSys == "Windows"){
-  linux <- FALSE
+  windows <- TRUE
 } else {
-  linux <- TRUE
+  windows <- FALSE
 }
 
+
 reportName <- "BrowserExampleMathJax.html"
 
 ### Packages required
@@ -30,12 +31,12 @@ br <- function(page){
   hwrite("", page, br = TRUE)
 }
 ### Open file for writing
-p <- newPage(reportName,
-             title = "Example of a Document for Display in a Browser",
-             link.css = c("../css/BrowserExample.css"),
-             link.javascript =
-             c("http://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML"))
-br(p)
+pg <- newPage(reportName,
+              title = "Example of a Document for Display in a Browser",
+              link.css = c("../css/BrowserExample.css"),
+              link.javascript =
+              c("http://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS-MML_HTMLorMML"))
+br(pg)
 
 ### Check if values have been set
 hwriterEquation
@@ -43,37 +44,37 @@ hwriterEquationList
 
 hwrite("<span class = 'title'>
        Example of a Document for Display in a Browser</span>",
-       p, center = TRUE, br = TRUE)
+       pg, center = TRUE, br = TRUE)
 hwrite("<span class = 'subtitle'>
        Dr David J Scott</span>",
-       p, center = TRUE, br = TRUE)
-hwrite(hwrite("Entering Text", name = "intro"), p,
+       pg, center = TRUE, br = TRUE)
+hwrite(hwrite("Entering Text", name = "intro"), pg,
        heading = 1, center = FALSE, br = TRUE)
 hwrite("Ordinary paragraph text can be entering using
 <font face = 'monospace' >hwrite</font>.
 Aspects of the text such as the font family, face, size and colour can
-be altered in line by using tags or styles.", p,
+be altered in line by using tags or styles.", pg,
        center = FALSE, br = TRUE)
-br(p)
+br(pg)
 hwrite("For example the font can be changed to sans-serif
 <font face = 'Arial, sans-serif'> like this, </font>
 italic <i> like this, </i> bold <b> like this,</b> coloured
 <font color = 'blue'> like this,</font> or any combination of these
-<b><i><font color = 'blue'>like this.</font></i></b>", p, br = TRUE)
-br(p)
+<b><i><font color = 'blue'>like this.</font></i></b>", pg, br = TRUE)
+br(pg)
 
 hwrite("Some text variations may not be rendered appropriately as can be
 seen in the examples above. Classes can be defined in the
 <span class = 'pkg'>.css</span> file
-to deal with this problem.", p, br = TRUE)
-br(p)
+to deal with this problem.", pg, br = TRUE)
+br(pg)
 
 hwrite("Incorporating Special Symbols",
-       p, heading = 1, center = FALSE, br = TRUE)
+       pg, heading = 1, center = FALSE, br = TRUE)
 hwrite("Using appropriate tags and a list of symbols it is possible to
 output mathematical and other symbols. Superscripts and subscripts are
-also possible.", p, br = TRUE)
-br(p)
+also possible.", pg, br = TRUE)
+br(pg)
 hwrite("Here are some Greek letters: &alpha;
 &beta; and &Gamma;,
 followed by some examples of superscripts and subscripts:
@@ -81,8 +82,8 @@ followed by some examples of superscripts and subscripts:
 of other symbols, here are some arrows:
 &larr;  and &rArr;, some set symbols:
 &exist;  and &cap;, and some operators:
-&int;  and &prod;.", p, br = TRUE)
-br(p)
+&int;  and &prod;.", pg, br = TRUE)
+br(pg)
 hwrite("More than one approach is
 available to produce mathematical symbols.
 Greek letters can be produced by using symbol font:
@@ -90,14 +91,14 @@ Greek letters can be produced by using symbol font:
 work in some browsers without the presence of additional fonts.
 Codes can be used instead of \\(\\LaTeX\\)-like names:
 &#8592;, &#8747; and &#8719;",
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 hwrite("Quotes can be incorporated by escaping with \"\\\",
 so for example we can obtain \" and \' in the middle of some text.",
-       p, br = TRUE)
+       pg, br = TRUE)
 
 ### Mathematics
-hwrite("Rendering Mathematics", p, id = "mathematics",
+hwrite("Rendering Mathematics", pg, id = "mathematics",
        heading = 1, center = FALSE, br = TRUE)
 hwrite("Entering more complex mathematical expressions including
 displayed mathematical expressions is difficult.
@@ -105,10 +106,9 @@ One approach is to insert
 an image produced by other means, for example by \\(\\LaTeX\\) or Word's
 equation editor. The following expression was produced by Word's
 equation editor then saved as a jpeg.",
-       p, br = TRUE)
-br(p)
-hwriteImage("DisplayedEquation.jpg", p, center = TRUE, br = TRUE)
-#hwriteImage("AltDisplayedEquation.jpg", p, center = TRUE, br = TRUE)
+       pg, br = TRUE)
+br(pg)
+hwriteImage("DisplayedEquation.jpg", pg, center = TRUE, br = TRUE)
 
 hwrite("To enable the rendering of complex mathematical expressions
 using \\(\\LaTeX\\) syntax, JavaScript is required, the JavaScript being
@@ -123,39 +123,39 @@ MathPlayer does not work reliably in all browsers and may require an
 add-on to function. MathJax is preferred for these reasons in extending
 the capabilities of <span class = 'pkg'> hwriter</span> in the
 <span class = 'pkg'> hwriterPlus</span> package",
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 hwrite("Here is an inline expression:\\(\\int_{-\\infty}^{1}f(x)dx\\),
 followed by two displayed expressions, one of which is numbered and
 has also been assigned a label.
 The first example also has a box around it, by assigning the value
 <font face = 'monospace'> \"border = '1'\"</font> to the argument
 <font face = 'monospace'> table.attributes</font>.",
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 
 
 hwriteLatex(as.latex("\\int_{-\\infty}^{1}f(x)dx",
                      inline = FALSE, count = FALSE),
-            page = p,
+            page = pg,
             table.attributes = "border = '1'",
             tr.attributes = "bgcolor = 'white'")
 
 hwriteLatex(as.latex("\\{ 26.119 < \\sum_{i=1}^n(X_i-\\bar{X})^2\\}
 \\bigcup\\ \\{ 5.629 > \\sum_{i=1}^n (X_i-\\bar{X})^2 \\}.",
                      inline = FALSE, label = "equation1"),
-            page = p,
+            page = pg,
             tr.attributes = "bgcolor = 'white'",
             td.attributes = c("width = '50'", "align = 'center'",
                               "align = 'right' width = '50'"))
-br(p)
+br(pg)
 
 ### Check again on equation numbering
 hwriterEquation
 hwriterEquationList
 
 ### Images
-hwrite("Incorporating Images", p,
+hwrite("Incorporating Images", pg,
        heading = 1, center = FALSE, br = TRUE)
 hwrite("Incorporating images is complicated by the inability of
 different browsers to display images in different formats.
@@ -164,11 +164,12 @@ The only scalable image format which can be displayed by all the
 common browsers (Internet Explorer, Firefox, Safari and Chrome)
 appears to be <span class ='pkg'>.svg</span>,
 scalable vector graphics.",
-        p, center = FALSE, br = TRUE)
-br(p)
+        pg, center = FALSE, br = TRUE)
+br(pg)
 hwrite(paste("Here is a windows metafile, <span class ='pkg'>.wmf</span> image.
-Unfortunately this will only display in Internet Explorer, and there
-will be no output produced at all if this example is run on linux.
+Unfortunately this will only display in Internet Explorer (or Microsoft Word),
+and there will be no output produced at all if the operating system is not
+Microsoft Windows.
 The example is the cats data used by Leisch as an Sweave example,
 taken from Venables and Ripley (1987).
 The data frame contains measurements of heart and body weight
@@ -176,77 +177,80 @@ of ",
              nrow(cats), " cats (",
              sum(cats$Sex=='F')," female, ",
              sum(cats$Sex=='F')," male).", sep = ""),
-       p, center = FALSE, br = TRUE)
-br(p)
+       pg, center = FALSE, br = TRUE)
+br(pg)
 hwrite("A linear regression model of heart weight by sex and gender was
 fitted to this data. The graph is a scatter plot of the data including
-the regression lines",
-       p, center = FALSE, br = TRUE)
-br(p)
+the regression lines.",
+       pg, center = FALSE, br = TRUE)
+br(pg)
 ### Fit linear model
 lm1 <- lm(Hwt~Bwt*Sex, data=cats)
 lm1
 lattice.options(theme = "col.whitebg")
+
 ### Draw graph
-if (!linux) {
+if (windows) {
   win.metafile("cats.wmf", height = 4)
   print(xyplot(Hwt~Bwt|Sex, data=cats, type=c("p", "r")))
   dev.off()
-  hwriteImage("cats.wmf", p, center = FALSE, br = TRUE)
+  hwriteImage("cats.wmf", pg, center = FALSE, br = TRUE)
 }
 
 
+
+
 hwrite("Here is the cats data plot in svg format.
 This uses an extension to hwriter to produce HTML code which enables
 display in up to date versions of all common browsers.",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 CairoSVG("cats.svg", width = 4, height = 4)
 lattice.options(theme = "col.whitebg")
 print(xyplot(Hwt~Bwt|Sex, data=cats, type=c("p", "r")))
 dev.off()
-hwriteSVG("cats.svg", p, height = 600, width = 600, id = "catsSVG",
+hwriteSVG("cats.svg", pg, height = 600, width = 600, id = "catsSVG",
           center = FALSE, br = TRUE)
 
 hwrite("A further format is png (portable network graphics).
 This should display in up to date versions of all common browsers.
 It is a bitmap format however so not scalable.",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 CairoPNG("cats.png", width = 4*80, height = 4*80)
 
 lattice.options(theme = "col.whitebg")
 print(xyplot(Hwt~Bwt|Sex, data=cats, type=c("p", "r")))
 dev.off()
-hwriteImage("cats.png", p, center = FALSE, br = TRUE)
+hwriteImage("cats.png", pg, center = FALSE, br = TRUE)
 
 hwrite("One problem with images is that the size of the image displayed
 can vary widely from browser to browser. Obtaining the right sized image
 for a particular browser may require a lot of trial and error.",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 
 ### Vectors, matrices and dataframes
-hwrite("Vectors, Matrices and Dataframes", p,
+hwrite("Vectors, Matrices and Dataframes", pg,
        heading = 1, center = FALSE, br = TRUE)
-hwrite("Here is some code producing a character vector", p,
+hwrite("Here is some code producing a character vector", pg,
        center = FALSE, br = TRUE)
 form <- y ~ a + b + c
 example <- as.character(form)
 hwriteOutput(
 "form <- y ~ a + b + c
-example <- as.character(form)", p, br = TRUE)
-hwrite("This is the result of printing the vector", p,
+example <- as.character(form)", pg, br = TRUE)
+hwrite("This is the result of printing the vector", pg,
        center = FALSE, br = TRUE)
-hwrite(example, p,
+hwrite(example, pg,
        center = TRUE, br = TRUE)
 
-hwrite("Here is some code producing a numeric vector", p,
+hwrite("Here is some code producing a numeric vector", pg,
        center = FALSE, br = TRUE)
 y <- 3*(1:5)
-hwriteOutput("y <- 3*(1:5)", p, br = TRUE)
-hwrite("This is the result of printing the vector", p,
+hwriteOutput("y <- 3*(1:5)", pg, br = TRUE)
+hwrite("This is the result of printing the vector", pg,
        center = FALSE, br = TRUE)
-hwrite(y, p,
+hwrite(y, pg,
        center = TRUE, br = TRUE)
-hwrite("Here is some code producing a matrix", p,
+hwrite("Here is some code producing a matrix", pg,
        center = FALSE, br = TRUE)
 mdat <- matrix(c(1,2,3, 11,12,13),
                nrow = 2, ncol = 3, byrow = TRUE,
@@ -257,12 +261,12 @@ hwriteOutput(
                nrow = 2, ncol = 3, byrow = TRUE,
                dimnames = list(c('row1', 'row2'),
                                c('C.1', 'C.2', 'C.3')))",
-             p, br = TRUE)
-hwrite("This is the result of printing the matrix", p,
+             pg, br = TRUE)
+hwrite("This is the result of printing the matrix", pg,
        center = FALSE, br = TRUE)
-hwrite(mdat, p,
+hwrite(mdat, pg,
        center = TRUE, br = TRUE)
-hwrite("Here is some code producing a dataframe", p,
+hwrite("Here is some code producing a dataframe", pg,
        center = FALSE, br = TRUE)
 L3 <- LETTERS[1:3]
 d <- data.frame(cbind(x = 1, y = 1:10),
@@ -271,44 +275,44 @@ hwriteOutput(
 "L3 <- LETTERS[1:3]
 d <- data.frame(cbind(x = 1, y = 1:10),
                 fac = sample(L3, 10, replace = TRUE))",
-             p, center = FALSE, br = TRUE)
-hwrite("This is the result of printing the dataframe", p,
+             pg, center = FALSE, br = TRUE)
+hwrite("This is the result of printing the dataframe", pg,
        center = FALSE, br = TRUE)
-hwrite(d, p,
+hwrite(d, pg,
        center = TRUE, br = TRUE)
 
 
 ### Tables
-hwrite("Tables", p, heading = 2, center = FALSE, br = TRUE)
+hwrite("Tables", pg, heading = 2, center = FALSE, br = TRUE)
 hwrite("Here is an example taken from the documentation of
 <font face='monospace'>xtable</font>. It shows the output of an
 ANOVA table.",
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 require(xtable)
 data(tli)
 fm1 <- aov(tlimth ~ sex + ethnicty + grade + disadvg, data=tli)
 fm1.table <- print(xtable(fm1), type="html")
 
-hwrite(fm1.table, p, center = TRUE, br = TRUE)
+hwrite(fm1.table, pg, center = TRUE, br = TRUE)
 hwrite("Here is an example taken from the documentation of
 <font face='monospace'>table</font>. It shows the output of a
 two-dimensional table.",
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 require(stats)
 tbl <- print(xtable(table(state.division, state.region)), type = "html")
-hwrite(tbl, p, center = TRUE, br = TRUE)
+hwrite(tbl, pg, center = TRUE, br = TRUE)
 
 ### Output
-hwrite("R Output", p, heading = 2, center = FALSE, br = FALSE)
+hwrite("R Output", pg, heading = 2, center = FALSE, br = FALSE)
 hwrite("To include output from R in a file, the
 command <code>capture.output</code> is used to record the output.
 Then the output is included in the HTML file by using the command
 <code>hwriteOutput</code>, which is not in the package
- <span class = 'pkg'>hwriter</span>.", p, center = FALSE, br = TRUE)
+ <span class = 'pkg'>hwriter</span>.", pg, center = FALSE, br = TRUE)
 hwrite("Here is an example from the <code>glm</code> help.",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 aggOut <-
     capture.output(data(iris),
                    str(iris),
@@ -321,15 +325,15 @@ hwriteOutput(
                    str(iris),
                    aggregate(Sepal.Length~Species, iris, mean)
                    )",
-             p, center = FALSE, br = TRUE)
-hwrite("This produces the following result.", p, center = FALSE, br = TRUE)
-hwriteOutput(aggOut, p, center = FALSE, br = TRUE)
+             pg, center = FALSE, br = TRUE)
+hwrite("This produces the following result.", pg, center = FALSE, br = TRUE)
+hwriteOutput(aggOut, pg, center = FALSE, br = TRUE)
 hwrite("Note the commas separating the parts of the output to be captured.
 See the help and examples for <code>capture.output</code> for details.",
-       p, br = TRUE)
+       pg, br = TRUE)
 
 ### R Session
-hwrite("An R Session", p, heading = 2, center = FALSE, br = FALSE)
+hwrite("An R Session", pg, heading = 2, center = FALSE, br = FALSE)
 hwrite("To capture an R session, or part of one, including both commands
 and output, the command <code>txtStart</code> from the package
 <span class = 'pkg'>TeachingDemos</span> can be used then
@@ -337,9 +341,9 @@ and output, the command <code>txtStart</code> from the package
 This requires writing to a file, and reading the results back
 from the file. A temporary file can used for holding the output.
 See <code>?tempfile</code>.",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 hwrite("Here is an example.",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 tmpFile <- tempfile("Session")
 #txtStart("Temp1.txt")
 txtStart(tmpFile)
@@ -355,9 +359,9 @@ txtStop()
 #sessionOut <- readLines("Temp1.txt")
 sessionOut <- readLines(tmpFile)
 sessionOut
-hwriteOutput(sessionOut, p, br = TRUE)
+hwriteOutput(sessionOut, pg, br = TRUE)
 hwrite("An alternative approach which should not mangle line breaks is provided by the <code>script</code> function written by Ross Ihaka",
-       p, center = FALSE, br = TRUE)
+       pg, center = FALSE, br = TRUE)
 tmpFile <- tempfile("Session")
 script(tmpFile)
 clotting <-
@@ -371,21 +375,21 @@ coef(glm(lot1 ~ log(u), data=clotting, family=Gamma))
 q()
 sessionOut <- readLines(tmpFile)
 sessionOut
-hwriteOutput(sessionOut, p, br = TRUE)
+hwriteOutput(sessionOut, pg, br = TRUE)
 hwrite("The new function <code>hwriteScript</code> can be used to drop off lines at the beginning and end of the file created by <code>script</code>.",
-       p, center = FALSE, br = TRUE)
-hwriteScript(tmpFile, p, br = TRUE)
+       pg, center = FALSE, br = TRUE)
+hwriteScript(tmpFile, pg, br = TRUE)
 
 
 ### Links
-hwrite("Creating Links", p, heading = 2, center = FALSE, br = FALSE)
+hwrite("Creating Links", pg, heading = 2, center = FALSE, br = FALSE)
 hwrite("Since HTML is being produced, it is easy to create links to
 other websites. Here is an example of a link to the Statistics Department
 website: ",
-       p, br = FALSE)
-hwrite("The Department of Statistics.", p, br = TRUE,
+       pg, br = FALSE)
+hwrite("The Department of Statistics.", pg, br = TRUE,
        link = 'http://www.stat.auckland.ac.nz/uoa/')
-br(p)
+br(pg)
 hwrite("Links may be created within pages using anchors.
 Destination anchors in HTML documents may be specified either by the
 <font face = 'monospace'>a</font> element (naming it with the
@@ -393,25 +397,25 @@ Destination anchors in HTML documents may be specified either by the
 element (naming with the <font face = 'monospace'>id</font> attribute).
 Here is a link to the first section created using the
 <font face = 'monospace'>a</font> element: ",
-       p, br = FALSE)
-hwrite("Entering Text.", p, br = TRUE,
+       pg, br = FALSE)
+hwrite("Entering Text.", pg, br = TRUE,
        link = "#intro")
-br(p)
+br(pg)
 hwrite("Here is a link to the third section created by naming with
 the <font face = 'monospace'>id</font> attribute: ",
-       p, br = FALSE)
-hwrite("Rendering Mathematics.", p, br = TRUE,
+       pg, br = FALSE)
+hwrite("Rendering Mathematics.", pg, br = TRUE,
        link = "#mathematics")
-br(p)
+br(pg)
 hwrite("This use of named or identified elements of a documents is
 how cross-referencing can be implemented.",
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 hwrite("The numbered equation entered previously can be cross-referenced
 using the link argument to <font face = 'monospace'>hwrite</font>.
 That equation is equation 1 at present. Here is the link to the equation: ",
-       p, br = FALSE)
-hwrite("Numbered Equation.", p, br = TRUE,
+       pg, br = FALSE)
+hwrite("Numbered Equation.", pg, br = TRUE,
        link = "#eq:equation1")
 ### Test paste
 paste("We can also retrieve the number of a labeled equation.
@@ -428,18 +432,18 @@ using <code> which(hwriterEquationList == \"eq:equation1\")</code>
 which produces ",which(hwriterEquationList == "eq:equation1"),
 "or more easily using the convenience function <code>eqRef</code>,
 using simply <code>eqRef(\"equation1\")</code>."),
-       p, br = TRUE)
-br(p)
+       pg, br = TRUE)
+br(pg)
 hwrite("The graph in SVG format included previously can also be
 cross-referenced since it was assigned an identifier using the
 <font face = 'monospace'>id</font> attribute.
 Here is a link to that graph: ",
-       p, br = FALSE)
-hwrite("Graph in SVG format.", p, br = TRUE,
+       pg, br = FALSE)
+hwrite("Graph in SVG format.", pg, br = TRUE,
        link = "#catsSVG")
-br(p)
+br(pg)
 ### Close file
-closePage(p)
+closePage(pg)
 
 directory <- getwd()
 reportName <- paste("file://", directory, "/", reportName, sep = "")
